==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridRowEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditStartedEventArgsDescription } from "./GridRowEditStartedEventArgsDescription";
/**
 * @hidden
 */
var GridRowEditStartedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridRowEditStartedEventArgsDescriptionMetadata, _super);
    function GridRowEditStartedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridRowEditStartedEventArgsDescriptionMetadata.b = function (a) {
        if (GridRowEditStartedEventArgsDescriptionMetadata.a == null) {
            GridRowEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridRowEditStartedEventArgsDescriptionMetadata.c(GridRowEditStartedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridRowEditStartedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridRowEditStartedEventArgsDescriptionMetadata.a);
    };
    GridRowEditStartedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridRowEditStartedEventArgsDescriptionMetadata.d = function (a) {
        GridRowEditStartedEventArgsDescriptionMetadata.b(a);
        a.u("GridRowEditStartedEventArgs", function () { return new GridRowEditStartedEventArgsDescription(); });
        a.t("GridRowEditStartedEventArgs", GridRowEditStartedEventArgsDescriptionMetadata.a);
    };
    GridRowEditStartedEventArgsDescriptionMetadata.$t = markType(GridRowEditStartedEventArgsDescriptionMetadata, 'GridRowEditStartedEventArgsDescriptionMetadata');
    GridRowEditStartedEventArgsDescriptionMetadata.a = null;
    return GridRowEditStartedEventArgsDescriptionMetadata;
}(Base));
export { GridRowEditStartedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridRowEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditStartedEventArgsDescription } from "./GridRowEditStartedEventArgsDescription";
/**
 * @hidden
 */
var GridRowEditStartedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridRowEditStartedEventArgsDescriptionMetadata, _super);
    function GridRowEditStartedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridRowEditStartedEventArgsDescriptionMetadata.b = function (a) {
        if (GridRowEditStartedEventArgsDescriptionMetadata.a == null) {
            GridRowEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridRowEditStartedEventArgsDescriptionMetadata.c(GridRowEditStartedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridRowEditStartedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridRowEditStartedEventArgsDescriptionMetadata.a);
    };
    GridRowEditStartedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridRowEditStartedEventArgsDescriptionMetadata.d = function (a) {
        GridRowEditStartedEventArgsDescriptionMetadata.b(a);
        a.aa("GridRowEditStartedEventArgs", function () { return new GridRowEditStartedEventArgsDescription(); });
        a.z("GridRowEditStartedEventArgs", GridRowEditStartedEventArgsDescriptionMetadata.a);
    };
    GridRowEditStartedEventArgsDescriptionMetadata.$t = markType(GridRowEditStartedEventArgsDescriptionMetadata, 'GridRowEditStartedEventArgsDescriptionMetadata');
    GridRowEditStartedEventArgsDescriptionMetadata.a = null;
    return GridRowEditStartedEventArgsDescriptionMetadata;
}(Base));
export { GridRowEditStartedEventArgsDescriptionMetadata };
